==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/PartnerAuthorizationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.PartnerAuthorizationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The partner authorization details.
 * @property authorizedPartnersList The list of authorized partners.
 * @property defaultMaximumExpirationTimeInDays Time used to validate the authorization expiration time for each authorized partner. If DefaultMaximumExpirationTimeInDays is
 * not specified, the default is 7 days. Otherwise, allowed values are between 1 and 365 days.
 */
public data class PartnerAuthorizationArgs(
    public val authorizedPartnersList: Output<List<PartnerArgs>>? = null,
    public val defaultMaximumExpirationTimeInDays: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.PartnerAuthorizationArgs> {
    override fun toJava(): com.pulumi.azurenative.eventgrid.inputs.PartnerAuthorizationArgs =
        com.pulumi.azurenative.eventgrid.inputs.PartnerAuthorizationArgs.builder()
            .authorizedPartnersList(
                authorizedPartnersList?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .defaultMaximumExpirationTimeInDays(
                defaultMaximumExpirationTimeInDays?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [PartnerAuthorizationArgs].
 */
@PulumiTagMarker
public class PartnerAuthorizationArgsBuilder internal constructor() {
    private var authorizedPartnersList: Output<List<PartnerArgs>>? = null

    private var defaultMaximumExpirationTimeInDays: Output<Int>? = null

    /**
     * @param value The list of authorized partners.
     */
    @JvmName("xwlaalrugkqkqckg")
    public suspend fun authorizedPartnersList(`value`: Output<List<PartnerArgs>>) {
        this.authorizedPartnersList = value
    }

    @JvmName("vqvvjtawkccaxmkk")
    public suspend fun authorizedPartnersList(vararg values: Output<PartnerArgs>) {
        this.authorizedPartnersList = Output.all(values.asList())
    }

    /**
     * @param values The list of authorized partners.
     */
    @JvmName("erogphfqkvwiasbh")
    public suspend fun authorizedPartnersList(values: List<Output<PartnerArgs>>) {
        this.authorizedPartnersList = Output.all(values)
    }

    /**
     * @param value Time used to validate the authorization expiration time for each authorized partner. If DefaultMaximumExpirationTimeInDays is
     * not specified, the default is 7 days. Otherwise, allowed values are between 1 and 365 days.
     */
    @JvmName("oqigdvrvrlauobpu")
    public suspend fun defaultMaximumExpirationTimeInDays(`value`: Output<Int>) {
        this.defaultMaximumExpirationTimeInDays = value
    }

    /**
     * @param value The list of authorized partners.
     */
    @JvmName("qlpfvvvuurmwuwwq")
    public suspend fun authorizedPartnersList(`value`: List<PartnerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authorizedPartnersList = mapped
    }

    /**
     * @param argument The list of authorized partners.
     */
    @JvmName("hippcowfwylvepsk")
    public suspend fun authorizedPartnersList(argument: List<suspend PartnerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { PartnerArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.authorizedPartnersList = mapped
    }

    /**
     * @param argument The list of authorized partners.
     */
    @JvmName("qqpxrssmcsvbnguo")
    public suspend fun authorizedPartnersList(
        vararg
        argument: suspend PartnerArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map { PartnerArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.authorizedPartnersList = mapped
    }

    /**
     * @param argument The list of authorized partners.
     */
    @JvmName("xmymhwetdhxwpadh")
    public suspend fun authorizedPartnersList(argument: suspend PartnerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PartnerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.authorizedPartnersList = mapped
    }

    /**
     * @param values The list of authorized partners.
     */
    @JvmName("jacubkedkthfsnwp")
    public suspend fun authorizedPartnersList(vararg values: PartnerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authorizedPartnersList = mapped
    }

    /**
     * @param value Time used to validate the authorization expiration time for each authorized partner. If DefaultMaximumExpirationTimeInDays is
     * not specified, the default is 7 days. Otherwise, allowed values are between 1 and 365 days.
     */
    @JvmName("qyoecgranjlybsbp")
    public suspend fun defaultMaximumExpirationTimeInDays(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultMaximumExpirationTimeInDays = mapped
    }

    internal fun build(): PartnerAuthorizationArgs = PartnerAuthorizationArgs(
        authorizedPartnersList = authorizedPartnersList,
        defaultMaximumExpirationTimeInDays = defaultMaximumExpirationTimeInDays,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/PartnerAuthorizationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.PartnerAuthorizationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The partner authorization details.
 * @property authorizedPartnersList The list of authorized partners.
 * @property defaultMaximumExpirationTimeInDays Time used to validate the authorization expiration time for each authorized partner. If DefaultMaximumExpirationTimeInDays is
 * not specified, the default is 7 days. Otherwise, allowed values are between 1 and 365 days.
 */
public data class PartnerAuthorizationArgs(
    public val authorizedPartnersList: Output<List<PartnerArgs>>? = null,
    public val defaultMaximumExpirationTimeInDays: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.PartnerAuthorizationArgs> {
    override fun toJava(): com.pulumi.azurenative.eventgrid.inputs.PartnerAuthorizationArgs =
        com.pulumi.azurenative.eventgrid.inputs.PartnerAuthorizationArgs.builder()
            .authorizedPartnersList(
                authorizedPartnersList?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .defaultMaximumExpirationTimeInDays(
                defaultMaximumExpirationTimeInDays?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [PartnerAuthorizationArgs].
 */
@PulumiTagMarker
public class PartnerAuthorizationArgsBuilder internal constructor() {
    private var authorizedPartnersList: Output<List<PartnerArgs>>? = null

    private var defaultMaximumExpirationTimeInDays: Output<Int>? = null

    /**
     * @param value The list of authorized partners.
     */
    @JvmName("ifunlpgxlyhjskpa")
    public suspend fun authorizedPartnersList(`value`: Output<List<PartnerArgs>>) {
        this.authorizedPartnersList = value
    }

    @JvmName("axcscmbnxgwwghmj")
    public suspend fun authorizedPartnersList(vararg values: Output<PartnerArgs>) {
        this.authorizedPartnersList = Output.all(values.asList())
    }

    /**
     * @param values The list of authorized partners.
     */
    @JvmName("nbiphaujioqimbmi")
    public suspend fun authorizedPartnersList(values: List<Output<PartnerArgs>>) {
        this.authorizedPartnersList = Output.all(values)
    }

    /**
     * @param value Time used to validate the authorization expiration time for each authorized partner. If DefaultMaximumExpirationTimeInDays is
     * not specified, the default is 7 days. Otherwise, allowed values are between 1 and 365 days.
     */
    @JvmName("qgmuslfjlxbtqtoy")
    public suspend fun defaultMaximumExpirationTimeInDays(`value`: Output<Int>) {
        this.defaultMaximumExpirationTimeInDays = value
    }

    /**
     * @param value The list of authorized partners.
     */
    @JvmName("ifefonvsehhmqapf")
    public suspend fun authorizedPartnersList(`value`: List<PartnerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authorizedPartnersList = mapped
    }

    /**
     * @param argument The list of authorized partners.
     */
    @JvmName("arwjagyjgbphlxgo")
    public suspend fun authorizedPartnersList(argument: List<suspend PartnerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { PartnerArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.authorizedPartnersList = mapped
    }

    /**
     * @param argument The list of authorized partners.
     */
    @JvmName("breorxjkrcvmcjdf")
    public suspend fun authorizedPartnersList(
        vararg
        argument: suspend PartnerArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map { PartnerArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.authorizedPartnersList = mapped
    }

    /**
     * @param argument The list of authorized partners.
     */
    @JvmName("mivrtlylaggwvake")
    public suspend fun authorizedPartnersList(argument: suspend PartnerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PartnerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.authorizedPartnersList = mapped
    }

    /**
     * @param values The list of authorized partners.
     */
    @JvmName("mdrkgwremjitxmiu")
    public suspend fun authorizedPartnersList(vararg values: PartnerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authorizedPartnersList = mapped
    }

    /**
     * @param value Time used to validate the authorization expiration time for each authorized partner. If DefaultMaximumExpirationTimeInDays is
     * not specified, the default is 7 days. Otherwise, allowed values are between 1 and 365 days.
     */
    @JvmName("dpacbynekeusucga")
    public suspend fun defaultMaximumExpirationTimeInDays(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultMaximumExpirationTimeInDays = mapped
    }

    internal fun build(): PartnerAuthorizationArgs = PartnerAuthorizationArgs(
        authorizedPartnersList = authorizedPartnersList,
        defaultMaximumExpirationTimeInDays = defaultMaximumExpirationTimeInDays,
    )
}
